@@ -536,7 +536,7 @@ update_controller_callback (GList *result,
     case BIJI_ARCHIVED_ITEMS:
       bjb_window_base_switch_to (priv->window, BJB_WINDOW_BASE_ARCHIVE_VIEW);
       break;
-
+    case BIJI_LIVING_ITEMS:
     default:
       break;
   }
@@ -567,6 +567,8 @@ bjb_controller_apply_needle (BjbController *self)
     else
       update_controller_callback (result, self);
 
+    g_list_free (result);
+
     return;
   }
 
@@ -605,11 +607,8 @@ on_manager_changed (BijiManager            *manager,
   GtkTreeIter iter;
   GtkTreeIter *p_iter = &iter;
 
-  g_print ("manager changed\n");
-
   if (group != self->priv->group)
   {
-    g_print ("no controller\n");
     g_debug ("Controller received signal for group %i while %i",
              group, self->priv->group);
     return;
@@ -620,6 +619,11 @@ on_manager_changed (BijiManager            *manager,
 
   switch (flag)
   {
+    case BIJI_MANAGER_MASS_CHANGE:
+      bjb_controller_apply_needle (self);
+      g_timeout_add (1, (GSourceFunc) bjb_controller_set_window_active, self);
+      break;
+
     /* If this is a *new* item, per def prepend */
     case BIJI_MANAGER_ITEM_ADDED:
           if (BIJI_IS_NOTE_OBJ (item))
@@ -671,10 +675,10 @@ on_manager_changed (BijiManager            *manager,
      * Use another thread for this, because controller is now up to date,
      * and we need to unlock mutex,
      * since activating window can call this function! */
+
+    case BIJI_MANAGER_CHANGE_FLAG:
     default:
       bjb_controller_apply_needle (self);
-      if (flag == BIJI_MANAGER_MASS_CHANGE)
-        g_timeout_add (1, (GSourceFunc) bjb_controller_set_window_active, self);
   }
 
   g_mutex_unlock (&priv->mutex);
